From: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
To: stable@vger.kernel.org
Cc: Greg Kroah-Hartman <gregkh@linuxfoundation.org>,
patches@lists.linux.dev,
Przemek Kitszel <przemyslaw.kitszel@intel.com>,
Aleksandr Loktionov <aleksandr.loktionov@intel.com>,
Chittim Madhu <madhu.chittim@intel.com>,
Emil Tantilov <emil.s.tantilov@intel.com>,
Samuel Salin <Samuel.salin@intel.com>,
Tony Nguyen <anthony.l.nguyen@intel.com>,
Jakub Kicinski <kuba@kernel.org>, Sasha Levin <sashal@kernel.org>
Subject: [PATCH 6.18 124/181] idpf: convert vport state to bitmap
Date: Thu, 15 Jan 2026 17:47:41 +0100 [thread overview]
Message-ID: <20260115164206.790264849@linuxfoundation.org> (raw)
In-Reply-To: <20260115164202.305475649@linuxfoundation.org>
6.18-stable review patch. If anyone has any objections, please let me know.
------------------
From: Emil Tantilov <emil.s.tantilov@intel.com>
[ Upstream commit 8dd72ebc73f37b216410db17340f15e6fb2cdb7b ]
Convert vport state to a bitmap and remove the DOWN state which is
redundant in the existing logic. There are no functional changes aside
from the use of bitwise operations when setting and checking the states.
Removed the double underscore to be consistent with the naming of other
bitmaps in the header and renamed current_state to vport_is_up to match
the meaning of the new variable.
Reviewed-by: Przemek Kitszel <przemyslaw.kitszel@intel.com>
Reviewed-by: Aleksandr Loktionov <aleksandr.loktionov@intel.com>
Reviewed-by: Chittim Madhu <madhu.chittim@intel.com>
Signed-off-by: Emil Tantilov <emil.s.tantilov@intel.com>
Tested-by: Samuel Salin <Samuel.salin@intel.com>
Signed-off-by: Tony Nguyen <anthony.l.nguyen@intel.com>
Link: https://patch.msgid.link/20251125223632.1857532-6-anthony.l.nguyen@intel.com
Signed-off-by: Jakub Kicinski <kuba@kernel.org>
Stable-dep-of: 2e281e1155fc ("idpf: detach and close netdevs while handling a reset")
Signed-off-by: Sasha Levin <sashal@kernel.org>
---
drivers/net/ethernet/intel/idpf/idpf.h | 12 ++++------
.../net/ethernet/intel/idpf/idpf_ethtool.c | 12 +++++-----
drivers/net/ethernet/intel/idpf/idpf_lib.c | 24 +++++++++----------
.../ethernet/intel/idpf/idpf_singleq_txrx.c | 2 +-
drivers/net/ethernet/intel/idpf/idpf_txrx.c | 2 +-
.../net/ethernet/intel/idpf/idpf_virtchnl.c | 4 ++--
drivers/net/ethernet/intel/idpf/xdp.c | 2 +-
7 files changed, 28 insertions(+), 30 deletions(-)
diff --git a/drivers/net/ethernet/intel/idpf/idpf_ethtool.c b/drivers/net/ethernet/intel/idpf/idpf_ethtool.c
index a5a1eec9ade8b..eed166bc46f38 100644
--- a/drivers/net/ethernet/intel/idpf/idpf_ethtool.c
+++ b/drivers/net/ethernet/intel/idpf/idpf_ethtool.c
@@ -386,7 +386,7 @@ static int idpf_get_rxfh(struct net_device *netdev,
}
rss_data = &adapter->vport_config[np->vport_idx]->user_config.rss_data;
- if (np->state != __IDPF_VPORT_UP)
+ if (!test_bit(IDPF_VPORT_UP, np->state))
goto unlock_mutex;
rxfh->hfunc = ETH_RSS_HASH_TOP;
@@ -436,7 +436,7 @@ static int idpf_set_rxfh(struct net_device *netdev,
}
rss_data = &adapter->vport_config[vport->idx]->user_config.rss_data;
- if (np->state != __IDPF_VPORT_UP)
+ if (!test_bit(IDPF_VPORT_UP, np->state))
goto unlock_mutex;
if (rxfh->hfunc != ETH_RSS_HASH_NO_CHANGE &&
@@ -1167,7 +1167,7 @@ static void idpf_get_ethtool_stats(struct net_device *netdev,
idpf_vport_ctrl_lock(netdev);
vport = idpf_netdev_to_vport(netdev);
- if (np->state != __IDPF_VPORT_UP) {
+ if (!test_bit(IDPF_VPORT_UP, np->state)) {
idpf_vport_ctrl_unlock(netdev);
return;
@@ -1319,7 +1319,7 @@ static int idpf_get_q_coalesce(struct net_device *netdev,
idpf_vport_ctrl_lock(netdev);
vport = idpf_netdev_to_vport(netdev);
- if (np->state != __IDPF_VPORT_UP)
+ if (!test_bit(IDPF_VPORT_UP, np->state))
goto unlock_mutex;
if (q_num >= vport->num_rxq && q_num >= vport->num_txq) {
@@ -1507,7 +1507,7 @@ static int idpf_set_coalesce(struct net_device *netdev,
idpf_vport_ctrl_lock(netdev);
vport = idpf_netdev_to_vport(netdev);
- if (np->state != __IDPF_VPORT_UP)
+ if (!test_bit(IDPF_VPORT_UP, np->state))
goto unlock_mutex;
for (i = 0; i < vport->num_txq; i++) {
@@ -1710,7 +1710,7 @@ static void idpf_get_ts_stats(struct net_device *netdev,
ts_stats->err = u64_stats_read(&vport->tstamp_stats.discarded);
} while (u64_stats_fetch_retry(&vport->tstamp_stats.stats_sync, start));
- if (np->state != __IDPF_VPORT_UP)
+ if (!test_bit(IDPF_VPORT_UP, np->state))
goto exit;
for (u16 i = 0; i < vport->num_txq_grp; i++) {
diff --git a/drivers/net/ethernet/intel/idpf/idpf_lib.c b/drivers/net/ethernet/intel/idpf/idpf_lib.c
index 452f3107378cb..313803c088478 100644
--- a/drivers/net/ethernet/intel/idpf/idpf_lib.c
+++ b/drivers/net/ethernet/intel/idpf/idpf_lib.c
@@ -519,7 +519,7 @@ static int idpf_del_mac_filter(struct idpf_vport *vport,
}
spin_unlock_bh(&vport_config->mac_filter_list_lock);
- if (np->state == __IDPF_VPORT_UP) {
+ if (test_bit(IDPF_VPORT_UP, np->state)) {
int err;
err = idpf_add_del_mac_filters(vport, np, false, async);
@@ -590,7 +590,7 @@ static int idpf_add_mac_filter(struct idpf_vport *vport,
if (err)
return err;
- if (np->state == __IDPF_VPORT_UP)
+ if (test_bit(IDPF_VPORT_UP, np->state))
err = idpf_add_del_mac_filters(vport, np, true, async);
return err;
@@ -894,7 +894,7 @@ static void idpf_vport_stop(struct idpf_vport *vport, bool rtnl)
{
struct idpf_netdev_priv *np = netdev_priv(vport->netdev);
- if (np->state <= __IDPF_VPORT_DOWN)
+ if (!test_bit(IDPF_VPORT_UP, np->state))
return;
if (rtnl)
@@ -921,7 +921,7 @@ static void idpf_vport_stop(struct idpf_vport *vport, bool rtnl)
idpf_xdp_rxq_info_deinit_all(vport);
idpf_vport_queues_rel(vport);
idpf_vport_intr_rel(vport);
- np->state = __IDPF_VPORT_DOWN;
+ clear_bit(IDPF_VPORT_UP, np->state);
if (rtnl)
rtnl_unlock();
@@ -1345,7 +1345,7 @@ static int idpf_up_complete(struct idpf_vport *vport)
netif_tx_start_all_queues(vport->netdev);
}
- np->state = __IDPF_VPORT_UP;
+ set_bit(IDPF_VPORT_UP, np->state);
return 0;
}
@@ -1391,7 +1391,7 @@ static int idpf_vport_open(struct idpf_vport *vport, bool rtnl)
struct idpf_vport_config *vport_config;
int err;
- if (np->state != __IDPF_VPORT_DOWN)
+ if (test_bit(IDPF_VPORT_UP, np->state))
return -EBUSY;
if (rtnl)
@@ -1602,7 +1602,7 @@ void idpf_init_task(struct work_struct *work)
/* Once state is put into DOWN, driver is ready for dev_open */
np = netdev_priv(vport->netdev);
- np->state = __IDPF_VPORT_DOWN;
+ clear_bit(IDPF_VPORT_UP, np->state);
if (test_and_clear_bit(IDPF_VPORT_UP_REQUESTED, vport_config->flags))
idpf_vport_open(vport, true);
@@ -1796,7 +1796,7 @@ static void idpf_set_vport_state(struct idpf_adapter *adapter)
continue;
np = netdev_priv(adapter->netdevs[i]);
- if (np->state == __IDPF_VPORT_UP)
+ if (test_bit(IDPF_VPORT_UP, np->state))
set_bit(IDPF_VPORT_UP_REQUESTED,
adapter->vport_config[i]->flags);
}
@@ -1934,7 +1934,7 @@ int idpf_initiate_soft_reset(struct idpf_vport *vport,
enum idpf_vport_reset_cause reset_cause)
{
struct idpf_netdev_priv *np = netdev_priv(vport->netdev);
- enum idpf_vport_state current_state = np->state;
+ bool vport_is_up = test_bit(IDPF_VPORT_UP, np->state);
struct idpf_adapter *adapter = vport->adapter;
struct idpf_vport *new_vport;
int err;
@@ -1985,7 +1985,7 @@ int idpf_initiate_soft_reset(struct idpf_vport *vport,
goto free_vport;
}
- if (current_state <= __IDPF_VPORT_DOWN) {
+ if (!vport_is_up) {
idpf_send_delete_queues_msg(vport);
} else {
set_bit(IDPF_VPORT_DEL_QUEUES, vport->flags);
@@ -2018,7 +2018,7 @@ int idpf_initiate_soft_reset(struct idpf_vport *vport,
if (err)
goto err_open;
- if (current_state == __IDPF_VPORT_UP)
+ if (vport_is_up)
err = idpf_vport_open(vport, false);
goto free_vport;
@@ -2028,7 +2028,7 @@ int idpf_initiate_soft_reset(struct idpf_vport *vport,
vport->num_rxq, vport->num_bufq);
err_open:
- if (current_state == __IDPF_VPORT_UP)
+ if (vport_is_up)
idpf_vport_open(vport, false);
free_vport:
diff --git a/drivers/net/ethernet/intel/idpf/idpf_singleq_txrx.c b/drivers/net/ethernet/intel/idpf/idpf_singleq_txrx.c
index 61e6130661404..e3ddf18dcbf51 100644
--- a/drivers/net/ethernet/intel/idpf/idpf_singleq_txrx.c
+++ b/drivers/net/ethernet/intel/idpf/idpf_singleq_txrx.c
@@ -570,7 +570,7 @@ static bool idpf_tx_singleq_clean(struct idpf_tx_queue *tx_q, int napi_budget,
np = netdev_priv(tx_q->netdev);
nq = netdev_get_tx_queue(tx_q->netdev, tx_q->idx);
- dont_wake = np->state != __IDPF_VPORT_UP ||
+ dont_wake = !test_bit(IDPF_VPORT_UP, np->state) ||
!netif_carrier_ok(tx_q->netdev);
__netif_txq_completed_wake(nq, ss.packets, ss.bytes,
IDPF_DESC_UNUSED(tx_q), IDPF_TX_WAKE_THRESH,
diff --git a/drivers/net/ethernet/intel/idpf/idpf_txrx.c b/drivers/net/ethernet/intel/idpf/idpf_txrx.c
index 828f7c444d309..1993a3b0da59b 100644
--- a/drivers/net/ethernet/intel/idpf/idpf_txrx.c
+++ b/drivers/net/ethernet/intel/idpf/idpf_txrx.c
@@ -2275,7 +2275,7 @@ static bool idpf_tx_clean_complq(struct idpf_compl_queue *complq, int budget,
/* Update BQL */
nq = netdev_get_tx_queue(tx_q->netdev, tx_q->idx);
- dont_wake = !complq_ok || np->state != __IDPF_VPORT_UP ||
+ dont_wake = !complq_ok || !test_bit(IDPF_VPORT_UP, np->state) ||
!netif_carrier_ok(tx_q->netdev);
/* Check if the TXQ needs to and can be restarted */
__netif_txq_completed_wake(nq, tx_q->cleaned_pkts, tx_q->cleaned_bytes,
diff --git a/drivers/net/ethernet/intel/idpf/idpf_virtchnl.c b/drivers/net/ethernet/intel/idpf/idpf_virtchnl.c
index fc03d55bc9b90..5bbe7d9294c14 100644
--- a/drivers/net/ethernet/intel/idpf/idpf_virtchnl.c
+++ b/drivers/net/ethernet/intel/idpf/idpf_virtchnl.c
@@ -68,7 +68,7 @@ static void idpf_handle_event_link(struct idpf_adapter *adapter,
vport->link_up = v2e->link_status;
- if (np->state != __IDPF_VPORT_UP)
+ if (!test_bit(IDPF_VPORT_UP, np->state))
return;
if (vport->link_up) {
@@ -2760,7 +2760,7 @@ int idpf_send_get_stats_msg(struct idpf_vport *vport)
/* Don't send get_stats message if the link is down */
- if (np->state <= __IDPF_VPORT_DOWN)
+ if (!test_bit(IDPF_VPORT_UP, np->state))
return 0;
stats_msg.vport_id = cpu_to_le32(vport->vport_id);
diff --git a/drivers/net/ethernet/intel/idpf/xdp.c b/drivers/net/ethernet/intel/idpf/xdp.c
index 21ce25b0567f6..958d16f874248 100644
--- a/drivers/net/ethernet/intel/idpf/xdp.c
+++ b/drivers/net/ethernet/intel/idpf/xdp.c
@@ -418,7 +418,7 @@ static int idpf_xdp_setup_prog(struct idpf_vport *vport,
if (test_bit(IDPF_REMOVE_IN_PROG, vport->adapter->flags) ||
!test_bit(IDPF_VPORT_REG_NETDEV, cfg->flags) ||
!!vport->xdp_prog == !!prog) {
- if (np->state == __IDPF_VPORT_UP)
+ if (test_bit(IDPF_VPORT_UP, np->state))
idpf_xdp_copy_prog_to_rqs(vport, prog);
old = xchg(&vport->xdp_prog, prog);
diff --git a/drivers/net/ethernet/intel/idpf/idpf.h b/drivers/net/ethernet/intel/idpf/idpf.h
index ca4da0c899794..64142f8163fed 100644
--- a/drivers/net/ethernet/intel/idpf/idpf.h
+++ b/drivers/net/ethernet/intel/idpf/idpf.h
@@ -131,14 +131,12 @@ enum idpf_cap_field {
/**
* enum idpf_vport_state - Current vport state
* @__IDPF_VPORT_DOWN: Vport is down
* @__IDPF_VPORT_UP: Vport is up
* @__IDPF_VPORT_STATE_LAST: Must be last, number of states
*/
enum idpf_vport_state {
- __IDPF_VPORT_DOWN,
- __IDPF_VPORT_UP,
- __IDPF_VPORT_STATE_LAST,
+ IDPF_VPORT_UP,
+ IDPF_VPORT_STATE_NBITS
};
/**
@@ -162,7 +160,7 @@ struct idpf_netdev_priv {
u16 vport_idx;
u16 max_tx_hdr_size;
u16 tx_max_bufs;
- enum idpf_vport_state state;
+ DECLARE_BITMAP(state, IDPF_VPORT_STATE_NBITS);
struct rtnl_link_stats64 netstats;
spinlock_t stats_lock;
};
@@ -131,14 +131,12 @@ enum idpf_cap_field {
/**
* enum idpf_vport_state - Current vport state
- * @__IDPF_VPORT_DOWN: Vport is down
- * @__IDPF_VPORT_UP: Vport is up
- * @__IDPF_VPORT_STATE_LAST: Must be last, number of states
+ * @IDPF_VPORT_UP: Vport is up
+ * @IDPF_VPORT_STATE_NBITS: Must be last, number of states
*/
enum idpf_vport_state {
--
2.51.0
next prev parent reply other threads:[~2026-01-15 16:57 UTC|newest]
Thread overview: 196+ messages / expand[flat|nested] mbox.gz Atom feed top
2026-01-15 16:45 [PATCH 6.18 000/181] 6.18.6-rc1 review Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 001/181] NFSD: Fix permission check for read access to executable-only files Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 002/181] nfsd: provide locking for v4_end_grace Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 003/181] nfsd: use correct loop termination in nfsd4_revoke_states() Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 004/181] nfsd: check that server is running in unlock_filesystem Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 005/181] NFSD: net ref data still needs to be freed even if net hasnt startup Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 006/181] NFSD: Remove NFSERR_EAGAIN Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 007/181] atm: Fix dma_free_coherent() size Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 008/181] net: 3com: 3c59x: fix possible null dereference in vortex_probe1() Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 009/181] net: do not write to msg_get_inq in callee Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 010/181] arm64: Fix cleared E0POE bit after cpu_suspend()/resume() Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 011/181] bnxt_en: Fix NULL pointer crash in bnxt_ptp_enable during error cleanup Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 012/181] btrfs: always detect conflicting inodes when logging inode refs Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 013/181] mei: me: add nova lake point S DID Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 014/181] rust_binder: remove spin_lock() in rust_shrink_free_page() Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 015/181] lib/crypto: aes: Fix missing MMU protection for AES S-box Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 016/181] counter: 104-quad-8: Fix incorrect return value in IRQ handler Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 017/181] counter: interrupt-cnt: Drop IRQF_NO_THREAD flag Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 018/181] tracing: Add recursion protection in kernel stack trace recording Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 019/181] riscv: boot: Always make Image from vmlinux, not vmlinux.unstripped Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 020/181] nouveau: dont attempt fwsec on sb on newer platforms Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 021/181] Revert "drm/atomic-helper: Re-order bridge chain pre-enable and post-disable" Greg Kroah-Hartman
2026-01-15 16:45 ` [PATCH 6.18 022/181] ALSA: ac97: fix a double free in snd_ac97_controller_register() Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 023/181] ALSA: hda/tas2781: properly initialize speaker_id for TAS2563 Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 024/181] arm64: dts: imx95: correct I3C2 pclk to IMX95_CLK_BUSWAKEUP Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 025/181] drm/amd/display: Apply e4479aecf658 to dml Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 026/181] drm/amdgpu: Fix query for VPE block_type and ip_count Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 027/181] drm/atomic-helper: Export and namespace some functions Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 028/181] drm/pl111: Fix error handling in pl111_amba_probe Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 029/181] drm/tidss: Fix enable/disable order Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 030/181] drm/radeon: Remove __counted_by from ClockInfoArray.clockInfo[] Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 031/181] gpio: rockchip: mark the GPIO controller as sleeping Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 032/181] io_uring/io-wq: fix incorrect io_wq_for_each_worker() termination logic Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 033/181] PCI: meson: Report that link is up while in ASPM L0s and L1 states Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 034/181] pinctrl: qcom: lpass-lpi: mark the GPIO controller as sleeping Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 035/181] PM: hibernate: Fix crash when freeing invalid crypto compressor Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 036/181] Revert "drm/mediatek: dsi: Fix DSI host and panel bridge pre-enable order" Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 037/181] wifi: avoid kernel-infoleak from struct iw_point Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 038/181] wifi: mac80211: restore non-chanctx injection behaviour Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 039/181] libceph: prevent potential out-of-bounds reads in handle_auth_done() Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 040/181] libceph: replace overzealous BUG_ON in osdmap_apply_incremental() Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 041/181] libceph: make free_choose_arg_map() resilient to partial allocation Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 042/181] libceph: return the handler error from mon_handle_auth_done() Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 043/181] libceph: reset sparse-read state in osd_fault() Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 044/181] libceph: make calc_target() set t->paused, not just clear it Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 045/181] ublk: reorder tag_set initialization before queue allocation Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 046/181] ALSA: hda: intel-dsp-config: Prefer legacy driver as fallback Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 047/181] csky: fix csky_cmpxchg_fixup not working Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 048/181] ARM: 9461/1: Disable HIGHPTE on PREEMPT_RT kernels Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 049/181] alpha: dont reference obsolete termio struct for TC* constants Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 050/181] dm-verity: disable recursive forward error correction Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 051/181] dm-snapshot: fix scheduling while atomic on real-time kernels Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 052/181] NFSv4: ensure the open stateid seqid doesnt go backwards Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 053/181] ASoC: rockchip: Fix Wvoid-pointer-to-enum-cast warning (again) Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 054/181] NFS: Fix up the automount fs_context to use the correct cred Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 055/181] ALSA: hda/realtek: Add support for ASUS UM3406GA Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 056/181] drm/amd/display: shrink struct members Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 057/181] smb/client: fix NT_STATUS_UNABLE_TO_FREE_VM value Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 058/181] smb/client: fix NT_STATUS_DEVICE_DOOR_OPEN value Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 059/181] smb/client: fix NT_STATUS_NO_DATA_DETECTED value Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 060/181] scsi: mpi3mr: Prevent duplicate SAS/SATA device entries in channel 1 Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 061/181] scsi: ipr: Enable/disable IRQD_NO_BALANCING during reset Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 062/181] scsi: ufs: core: Fix EH failure after W-LUN resume error Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 063/181] scsi: Revert "scsi: libsas: Fix exp-attached device scan after probe failure scanned in again after probe failed" Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 064/181] btrfs: fix qgroup_snapshot_quick_inherit() squota bug Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 065/181] btrfs: qgroup: update all parent qgroups when doing quick inherit Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 066/181] btrfs: fix NULL dereference on root when tracing inode eviction Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 067/181] btrfs: fix use-after-free warning in btrfs_get_or_create_delayed_node() Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 068/181] of: unittest: Fix memory leak in unittest_data_add() Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 069/181] arm64: dts: ti: k3-am642-phyboard-electra-peb-c-010: Fix icssg-prueth schema warning Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 070/181] arm64: dts: ti: k3-am642-phyboard-electra-x27-gpio1-spi1-uart3: Fix schema warnings Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 071/181] arm64: dts: ti: k3-am62-lp-sk-nand: Rename pinctrls to fix " Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 072/181] gpu: nova-core: select RUST_FW_LOADER_ABSTRACTIONS Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 073/181] gpio: it87: balance superio enter/exit calls in error path Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 074/181] HID: Intel-thc-hid: Intel-thc: fix dma_unmap_sg() nents value Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 075/181] HID: Intel-thc-hid: Intel-thc: Fix wrong register reading Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 076/181] netfs: Fix early read unlock of page with EOF in middle Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 077/181] pinctrl: mediatek: mt8189: restore previous register base name array order Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 078/181] crypto: qat - fix duplicate restarting msg during AER error Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 079/181] arm64: dts: imx8qm-mek: correct the light sensor interrupt type to low level Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 080/181] arm64: dts: add off-on-delay-us for usdhc2 regulator Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 081/181] ARM: dts: imx6q-ba16: fix RTC interrupt level Greg Kroah-Hartman
2026-01-15 16:46 ` [PATCH 6.18 082/181] arm64: dts: freescale: moduline-display: fix compatible Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 083/181] arm64: dts: freescale: tx8p-ml81: fix eqos nvmem-cells Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 084/181] arm64: dts: imx8mp: Fix LAN8740Ai PHY reference clock on DH electronics i.MX8M Plus DHCOM Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 085/181] arm64: dts: imx8qm-ss-dma: correct the dma channels of lpuart Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 086/181] arm64: dts: mba8mx: Fix Ethernet PHY IRQ support Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 087/181] netfilter: nft_set_pipapo: fix range overlap detection Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 088/181] netfilter: nft_synproxy: avoid possible data-race on update operation Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 089/181] gpiolib: remove unnecessary out of memory messages Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 090/181] gpiolib: rename GPIO chip printk macros Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 091/181] gpiolib: fix race condition for gdev->srcu Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 092/181] gpio: pca953x: handle short interrupt pulses on PCAL devices Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 093/181] netfilter: nf_tables: fix memory leak in nf_tables_newrule() Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 094/181] netfilter: nf_conncount: update last_gc only when GC has been performed Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 095/181] net: marvell: prestera: fix NULL dereference on devlink_alloc() failure Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 096/181] bridge: fix C-VLAN preservation in 802.1ad vlan_tunnel egress Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 097/181] net: mscc: ocelot: Fix crash when adding interface under a lag Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 098/181] inet: ping: Fix icmp out counting Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 099/181] net: phy: mxl-86110: Add power management and soft reset support Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 100/181] net: sock: fix hardened usercopy panic in sock_recv_errqueue Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 101/181] netdev: preserve NETIF_F_ALL_FOR_ALL across TSO updates Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 102/181] net/mlx5: Lag, multipath, give priority for routes with smaller network prefix Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 103/181] net/mlx5e: Dont gate FEC histograms on ppcnt_statistical_group Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 104/181] net/mlx5e: Dont print error message due to invalid module Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 105/181] net/mlx5e: Dealloc forgotten PSP RX modify header Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 106/181] net/ena: fix missing lock when update devlink params Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 107/181] net: wwan: iosm: Fix memory leak in ipc_mux_deinit() Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 108/181] bnxt_en: Fix potential data corruption with HW GRO/LRO Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 109/181] virtio_net: fix device mismatch in devm_kzalloc/devm_kfree Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 110/181] inet: frags: drop fraglist conntrack references Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 111/181] perf: Ensure swevent hrtimer is properly destroyed Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 112/181] drm/amd/pm: fix wrong pcie parameter on navi1x Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 113/181] drm/amd/pm: force send pcie parmater " Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 114/181] vsock: Make accept()ed sockets use custom setsockopt() Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 115/181] btrfs: release path before initializing extent tree in btrfs_read_locked_inode() Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 116/181] btrfs: only enforce free space tree if v1 cache is required for bs < ps cases Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 117/181] btrfs: fix NULL pointer dereference in do_abort_log_replay() Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 118/181] net: airoha: Fix npu rx DMA definitions Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 119/181] riscv: cpufeature: Fix Zk bundled extension missing Zknh Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 120/181] riscv: pgtable: Cleanup useless VA_USER_XXX definitions Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 121/181] net: fix memory leak in skb_segment_list for GRO packets Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 122/181] PCI/VGA: Dont assume the only VGA device on a system is `boot_vga` Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 123/181] idpf: keep the netdev when a reset fails Greg Kroah-Hartman
2026-01-15 16:47 ` Greg Kroah-Hartman [this message]
2026-01-15 16:47 ` [PATCH 6.18 125/181] idpf: detach and close netdevs while handling a reset Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 126/181] idpf: fix memory leak in idpf_vport_rel() Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 127/181] idpf: fix memory leak in idpf_vc_core_deinit() Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 128/181] idpf: fix error handling in the init_task on load Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 129/181] idpf: fix memory leak of flow steer list on rmmod Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 130/181] idpf: fix issue with ethtool -n command display Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 131/181] idpf: Fix RSS LUT NULL pointer crash on early ethtool operations Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 132/181] idpf: Fix RSS LUT configuration on down interfaces Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 133/181] idpf: Fix RSS LUT NULL ptr issue after soft reset Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 134/181] idpf: Fix error handling in idpf_vport_open() Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 135/181] idpf: cap maximum Rx buffer size Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 136/181] idpf: fix aux device unplugging when rdma is not supported by vport Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 137/181] Revert "dsa: mv88e6xxx: make serdes SGMII/Fiber tx amplitude configurable" Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 138/181] udp: call skb_orphan() before skb_attempt_defer_free() Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 139/181] net: sfp: return the number of written bytes for smbus single byte access Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 140/181] net/sched: act_api: avoid dereferencing ERR_PTR in tcf_idrinfo_destroy Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 141/181] selftests: drv-net: Bring back tool() to driver __init__s Greg Kroah-Hartman
2026-01-15 16:47 ` [PATCH 6.18 142/181] net: netdevsim: fix inconsistent carrier state after link/unlink Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 143/181] block: dont merge bios with different app_tags Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 144/181] trace: ftrace_dump_on_oops[] is not exported, make it static Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 145/181] sparc/PCI: Correct 64-bit non-pref -> pref BAR resources Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 146/181] HID: quirks: work around VID/PID conflict for appledisplay Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 147/181] net: airoha: Fix schedule while atomic in airoha_ppe_deinit() Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 148/181] wifi: mac80211_hwsim: fix typo in frequency notification Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 149/181] net/sched: sch_qfq: Fix NULL deref when deactivating inactive aggregate in qfq_reset Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 150/181] net: usb: pegasus: fix memory leak in update_eth_regs_async() Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 151/181] net: enetc: fix build warning when PAGE_SIZE is greater than 128K Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 152/181] arp: do not assume dev_hard_header() does not change skb->head Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 153/181] ublk: fix use-after-free in ublk_partition_scan_work Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 154/181] irqchip/gic-v5: Fix gicv5_its_map_event() ITTE read endianness Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 155/181] erofs: dont bother with s_stack_depth increasing for now Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 156/181] erofs: fix file-backed mounts no longer working on EROFS partitions Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 157/181] btrfs: truncate ordered extent when skipping writeback past i_size Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 158/181] btrfs: use variable for end offset in extent_writepage_io() Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 159/181] btrfs: fix beyond-EOF write handling Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 160/181] gpio: mpsse: ensure worker is torn down Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 161/181] gpio: mpsse: add quirk support Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 162/181] gpio: mpsse: fix reference leak in gpio_mpsse_probe() error paths Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 163/181] bpf, test_run: Subtract size of xdp_frame from allowed metadata size Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 164/181] bpf: Fix reference count leak in bpf_prog_test_run_xdp() Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 165/181] net: sfp: extend Potron XGSPON quirk to cover additional EEPROM variant Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 166/181] powercap: fix race condition in register_control_type() Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 167/181] powercap: fix sscanf() error return value handling Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 168/181] netfilter: nf_tables: avoid chain re-validation if possible Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 169/181] ata: libata-core: Disable LPM on ST2000DM008-2FR102 Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 170/181] accel/amdxdna: Block running under a hypervisor Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 171/181] drm/amd/display: Fix DP no audio issue Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 172/181] spi: mt65xx: Use IRQF_ONESHOT with threaded IRQ Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 173/181] drm/amdkfd: Fix improper NULL termination of queue restore SMI event string Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 174/181] can: j1939: make j1939_session_activate() fail if device is no longer registered Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 175/181] block: validate pi_offset integrity limit Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 176/181] ALSA: usb-audio: Update for native DSD support quirks Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 177/181] ASoC: amd: yc: Add quirk for Honor MagicBook X16 2025 Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 178/181] ALSA: hda/realtek: enable woofer speakers on Medion NM14LNL Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 179/181] ASoC: fsl_sai: Add missing registers to cache default Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 180/181] scsi: sg: Fix occasional bogus elapsed time that exceeds timeout Greg Kroah-Hartman
2026-01-15 16:48 ` [PATCH 6.18 181/181] spi: cadence-quadspi: Prevent lost complete() call during indirect read Greg Kroah-Hartman
2026-01-15 17:56 ` [PATCH 6.18 000/181] 6.18.6-rc1 review Ronald Warsow
2026-01-15 19:15 ` Brett A C Sheffield
2026-01-15 20:00 ` Slade Watkins
2026-01-15 22:40 ` Shuah Khan
2026-01-15 23:32 ` Florian Fainelli
2026-01-16 4:23 ` Takeshi Ogasawara
2026-01-16 9:56 ` Ron Economos
2026-01-16 11:23 ` Jon Hunter
2026-01-16 12:28 ` Peter Schneider
2026-01-16 16:23 ` Mark Brown
2026-01-16 17:51 ` Hardik Garg
2026-01-16 21:55 ` Brett Mastbergen
2026-01-17 14:49 ` Miguel Ojeda
2026-01-19 9:01 ` Jeffrin Thalakkottoor
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20260115164206.790264849@linuxfoundation.org \
--to=gregkh@linuxfoundation.org \
--cc=Samuel.salin@intel.com \
--cc=aleksandr.loktionov@intel.com \
--cc=anthony.l.nguyen@intel.com \
--cc=emil.s.tantilov@intel.com \
--cc=kuba@kernel.org \
--cc=madhu.chittim@intel.com \
--cc=patches@lists.linux.dev \
--cc=przemyslaw.kitszel@intel.com \
--cc=sashal@kernel.org \
--cc=stable@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox